mailr19475 - /branches/relax_disp/specific_analyses/relax_disp.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on April 13, 2013 - 18:26:
Author: bugman
Date: Sat Apr 13 18:26:17 2013
New Revision: 19475

URL: http://svn.gna.org/viewcvs/relax?rev=19475&view=rev
Log:
Fix for the relax_disp.cluster user function.

The 'free spins' category is now not deleted when empty.


Modified:
    branches/relax_disp/specific_analyses/relax_disp.py

Modified: branches/relax_disp/specific_analyses/relax_disp.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/relax_disp/specific_analyses/relax_disp.py?rev=19475&r1=19474&r2=19475&view=diff
==============================================================================
--- branches/relax_disp/specific_analyses/relax_disp.py (original)
+++ branches/relax_disp/specific_analyses/relax_disp.py Sat Apr 13 18:26:17 
2013
@@ -317,8 +317,10 @@
             # Then add the ID to the cluster.
             cdp.clustering[cluster_id].append(id)
 
         # Clean up - delete any empty clusters.
         for key in cdp.clustering.keys():
+            if key == 'free spins':
+                continue
             if cdp.clustering[key] == []:
                 cdp.clustering.pop(key)
 
@@ -317,8 +317,10 @@
             cdp.clustering[cluster_id].append(id)
 
-        # Clean up - delete any empty clusters.
+        # Clean up - delete any empty clusters (except the free spins).
         for key in cdp.clustering.keys():




Related Messages


Powered by MHonArc, Updated Sat Apr 13 19:00:02 2013